@@ -43,23 +43,27 @@
 
 // Konsole
 #include "BookmarkHandler.h"
-#include "SessionController.h"
-#include "ProfileList.h"
-#include "Session.h"
-#include "ViewContainer.h"
-#include "ViewManager.h"
-#include "SessionManager.h"
-#include "ProfileManager.h"
 #include "KonsoleSettings.h"
+#include "ViewManager.h"
 #include "WindowSystemInfo.h"
-#include "TerminalDisplay.h"
+
+#include "profile/ProfileList.h"
+#include "profile/ProfileManager.h"
+
+#include "session/Session.h"
+#include "session/SessionController.h"
+#include "session/SessionManager.h"
+
 #include "settings/ConfigurationDialog.h"
-#include "settings/TemporaryFilesSettings.h"
 #include "settings/GeneralSettings.h"
 #include "settings/ProfileSettings.h"
 #include "settings/TabBarSettings.h"
+#include "settings/TemporaryFilesSettings.h"
 #include "settings/ThumbnailsSettings.h"
 
+#include "terminalDisplay/TerminalDisplay.h"
+#include "widgets/ViewContainer.h"
+
 using namespace Konsole;
 
 MainWindow::MainWindow() :
@@ -344,16 +348,16 @@ void MainWindow::setupActions()
             &Konsole::MainWindow::openUrls);
 
     // Settings Menu
-    _toggleMenuBarAction = KStandardAction::showMenubar(menuBar(), SLOT(setVisible(bool)), collection);
+    _toggleMenuBarAction = KStandardAction::showMenubar(menuBar(), &QMenuBar::setVisible, collection);
     collection->setDefaultShortcut(_toggleMenuBarAction, Konsole::ACCEL + Qt::SHIFT + Qt::Key_M);
 
     // Full Screen
-    menuAction = KStandardAction::fullScreen(this, SLOT(viewFullScreen(bool)), this, collection);
+    menuAction = KStandardAction::fullScreen(this, &MainWindow::viewFullScreen, this, collection);
     collection->setDefaultShortcut(menuAction, Qt::Key_F11);
 
-    KStandardAction::configureNotifications(this, SLOT(configureNotifications()), collection);
-    KStandardAction::keyBindings(this, SLOT(showShortcutsDialog()), collection);
-    KStandardAction::preferences(this, SLOT(showSettingsDialog()), collection);
+    KStandardAction::configureNotifications(this, &MainWindow::configureNotifications, collection);
+    KStandardAction::keyBindings(this, &MainWindow::showShortcutsDialog, collection);
+    KStandardAction::preferences(this, &MainWindow::showSettingsDialog, collection);
 
     menuAction = collection->addAction(QStringLiteral("manage-profiles"));
     menuAction->setText(i18nc("@action:inmenu", "Manage Profiles..."));
@@ -801,7 +805,9 @@ void MainWindow::applyKonsoleSettings()
     }
 
     _viewManager->activeContainer()->setNavigationBehavior(KonsoleSettings::newTabBehavior());
-    setAutoSaveSettings(QStringLiteral("MainWindow"), KonsoleSettings::saveGeometryOnExit());
+    if (KonsoleSettings::saveGeometryOnExit() != autoSaveSettings()) {
+        setAutoSaveSettings(QStringLiteral("MainWindow"), KonsoleSettings::saveGeometryOnExit());
+    }
     updateWindowCaption();
 }
 
@@ -837,6 +843,12 @@ void MainWindow::setBlur(bool blur)
         return;
     }
 
+    // Saves 70-100ms when starting
+    if (blur == _blurEnabled) {
+        return;
+    }
+    _blurEnabled = blur;
+
     if (!_pluggedController->isKonsolePart()) {
         KWindowEffects::enableBlurBehind(winId(), blur);
     }
